/***************************************************************************\
* Module Name: Grecfr.C
*
* keyboard layout
*
* Copyright (c) 1985-2001, Microsoft Corporation
*
* History:
* KBDTOOL v3.40 - Created  Fri Mar 22 08:44:06 2013
\***************************************************************************/

#include <windows.h>
#include "kbd.h"
#include "Grecfr.h"

#if defined(_M_IA64)
#pragma section(".data")
#define ALLOC_SECTION_LDATA __declspec(allocate(".data"))
#else
#pragma data_seg(".data")
#define ALLOC_SECTION_LDATA
#endif

/***************************************************************************\
* ausVK[] - Virtual Scan Code to Virtual Key conversion table
\***************************************************************************/

static ALLOC_SECTION_LDATA USHORT ausVK[] = {
    T00, T01, T02, T03, T04, T05, T06, T07,
    T08, T09, T0A, T0B, T0C, T0D, T0E, T0F,
    T10, T11, T12, T13, T14, T15, T16, T17,
    T18, T19, T1A, T1B, T1C, T1D, T1E, T1F,
    T20, T21, T22, T23, T24, T25, T26, T27,
    T28, T29, T2A, T2B, T2C, T2D, T2E, T2F,
    T30, T31, T32, T33, T34, T35,

    /*
     * Right-hand Shift key must have KBDEXT bit set.
     */
    T36 | KBDEXT,

    T37 | KBDMULTIVK,               // numpad_* + Shift/Alt -> SnapShot

    T38, T39, T3A, T3B, T3C, T3D, T3E,
    T3F, T40, T41, T42, T43, T44,

    /*
     * NumLock Key:
     *     KBDEXT     - VK_NUMLOCK is an Extended key
     *     KBDMULTIVK - VK_NUMLOCK or VK_PAUSE (without or with CTRL)
     */
    T45 | KBDEXT | KBDMULTIVK,

    T46 | KBDMULTIVK,

    /*
     * Number Pad keys:
     *     KBDNUMPAD  - digits 0-9 and decimal point.
     *     KBDSPECIAL - require special processing by Windows
     */
    T47 | KBDNUMPAD | KBDSPECIAL,   // Numpad 7 (Home)
    T48 | KBDNUMPAD | KBDSPECIAL,   // Numpad 8 (Up),
    T49 | KBDNUMPAD | KBDSPECIAL,   // Numpad 9 (PgUp),
    T4A,
    T4B | KBDNUMPAD | KBDSPECIAL,   // Numpad 4 (Left),
    T4C | KBDNUMPAD | KBDSPECIAL,   // Numpad 5 (Clear),
    T4D | KBDNUMPAD | KBDSPECIAL,   // Numpad 6 (Right),
    T4E,
    T4F | KBDNUMPAD | KBDSPECIAL,   // Numpad 1 (End),
    T50 | KBDNUMPAD | KBDSPECIAL,   // Numpad 2 (Down),
    T51 | KBDNUMPAD | KBDSPECIAL,   // Numpad 3 (PgDn),
    T52 | KBDNUMPAD | KBDSPECIAL,   // Numpad 0 (Ins),
    T53 | KBDNUMPAD | KBDSPECIAL,   // Numpad . (Del),

    T54, T55, T56, T57, T58, T59, T5A, T5B,
    T5C, T5D, T5E, T5F, T60, T61, T62, T63,
    T64, T65, T66, T67, T68, T69, T6A, T6B,
    T6C, T6D, T6E, T6F, T70, T71, T72, T73,
    T74, T75, T76, T77, T78, T79, T7A, T7B,
    T7C, T7D, T7E

};

static ALLOC_SECTION_LDATA VSC_VK aE0VscToVk[] = {
        { 0x10, X10 | KBDEXT              },  // Speedracer: Previous Track
        { 0x19, X19 | KBDEXT              },  // Speedracer: Next Track
        { 0x1D, X1D | KBDEXT              },  // RControl
        { 0x20, X20 | KBDEXT              },  // Speedracer: Volume Mute
        { 0x21, X21 | KBDEXT              },  // Speedracer: Launch App 2
        { 0x22, X22 | KBDEXT              },  // Speedracer: Media Play/Pause
        { 0x24, X24 | KBDEXT              },  // Speedracer: Media Stop
        { 0x2E, X2E | KBDEXT              },  // Speedracer: Volume Down
        { 0x30, X30 | KBDEXT              },  // Speedracer: Volume Up
        { 0x32, X32 | KBDEXT              },  // Speedracer: Browser Home
        { 0x35, X35 | KBDEXT              },  // Numpad Divide
        { 0x37, X37 | KBDEXT              },  // Snapshot
        { 0x38, X38 | KBDEXT              },  // RMenu
        { 0x47, X47 | KBDEXT              },  // Home
        { 0x48, X48 | KBDEXT              },  // Up
        { 0x49, X49 | KBDEXT              },  // Prior
        { 0x4B, X4B | KBDEXT              },  // Left
        { 0x4D, X4D | KBDEXT              },  // Right
        { 0x4F, X4F | KBDEXT              },  // End
        { 0x50, X50 | KBDEXT              },  // Down
        { 0x51, X51 | KBDEXT              },  // Next
        { 0x52, X52 | KBDEXT              },  // Insert
        { 0x53, X53 | KBDEXT              },  // Delete
        { 0x5B, X5B | KBDEXT              },  // Left Win
        { 0x5C, X5C | KBDEXT              },  // Right Win
        { 0x5D, X5D | KBDEXT              },  // Application
        { 0x5F, X5F | KBDEXT              },  // Speedracer: Sleep
        { 0x65, X65 | KBDEXT              },  // Speedracer: Browser Search
        { 0x66, X66 | KBDEXT              },  // Speedracer: Browser Favorites
        { 0x67, X67 | KBDEXT              },  // Speedracer: Browser Refresh
        { 0x68, X68 | KBDEXT              },  // Speedracer: Browser Stop
        { 0x69, X69 | KBDEXT              },  // Speedracer: Browser Forward
        { 0x6A, X6A | KBDEXT              },  // Speedracer: Browser Back
        { 0x6B, X6B | KBDEXT              },  // Speedracer: Launch App 1
        { 0x6C, X6C | KBDEXT              },  // Speedracer: Launch Mail
        { 0x6D, X6D | KBDEXT              },  // Speedracer: Launch Media Selector
        { 0x1C, X1C | KBDEXT              },  // Numpad Enter
        { 0x46, X46 | KBDEXT              },  // Break (Ctrl + Pause)
        { 0,      0                       }
};

static ALLOC_SECTION_LDATA VSC_VK aE1VscToVk[] = {
        { 0x1D, Y1D                       },  // Pause
        { 0   ,   0                       }
};

/***************************************************************************\
* aVkToBits[]  - map Virtual Keys to Modifier Bits
*
* See kbd.h for a full description.
*
* The keyboard has only three shifter keys:
*     SHIFT (L & R) affects alphabnumeric keys,
*     CTRL  (L & R) is used to generate control characters
*     ALT   (L & R) used for generating characters by number with numpad
\***************************************************************************/
static ALLOC_SECTION_LDATA VK_TO_BIT aVkToBits[] = {
    { VK_SHIFT    ,   KBDSHIFT     },
    { VK_CONTROL  ,   KBDCTRL      },
    { VK_MENU     ,   KBDALT       },
    { 0           ,   0           }
};

/***************************************************************************\
* aModification[]  - map character modifier bits to modification number
*
* See kbd.h for a full description.
*
\***************************************************************************/

static ALLOC_SECTION_LDATA MODIFIERS CharModifiers = {
    &aVkToBits[0],
    7,
    {
    //  Modification# //  Keys Pressed
    //  ============= // =============
        0,            // 
        1,            // Shift 
        2,            // Control 
        SHFT_INVALID, // Shift + Control 
        SHFT_INVALID, // Menu 
        SHFT_INVALID, // Shift + Menu 
        3,            // Control + Menu 
        4             // Shift + Control + Menu 
     }
};

/***************************************************************************\
*
* aVkToWch2[]  - Virtual Key to WCHAR translation for 2 shift states
* aVkToWch3[]  - Virtual Key to WCHAR translation for 3 shift states
* aVkToWch4[]  - Virtual Key to WCHAR translation for 4 shift states
* aVkToWch5[]  - Virtual Key to WCHAR translation for 5 shift states
* aVkToWch6[]  - Virtual Key to WCHAR translation for 6 shift states
*
* Table attributes: Unordered Scan, null-terminated
*
* Search this table for an entry with a matching Virtual Key to find the
* corresponding unshifted and shifted WCHAR characters.
*
* Special values for VirtualKey (column 1)
*     0xff          - dead chars for the previous entry
*     0             - terminate the list
*
* Special values for Attributes (column 2)
*     CAPLOK bit    - CAPS-LOCK affect this key like SHIFT
*
* Special values for wch[*] (column 3 & 4)
*     WCH_NONE      - No character
*     WCH_DEAD      - Dead Key (diaresis) or invalid (US keyboard has none)
*     WCH_LGTR      - Ligature (generates multiple characters)
*
\***************************************************************************/

static ALLOC_SECTION_LDATA VK_TO_WCHARS2 aVkToWch2[] = {
//                      |         |  Shift  |
//                      |=========|=========|
  {VK_TAB       ,0      ,'\t'     ,'\t'     },
  {VK_ADD       ,0      ,'+'      ,'+'      },
  {VK_DIVIDE    ,0      ,'/'      ,'/'      },
  {VK_MULTIPLY  ,0      ,'*'      ,'*'      },
  {VK_SUBTRACT  ,0      ,'-'      ,'-'      },
  {0            ,0      ,0        ,0        }
};

static ALLOC_SECTION_LDATA VK_TO_WCHARS3 aVkToWch3[] = {
//                      |         |  Shift  |  Ctrl   |
//                      |=========|=========|=========|
  {VK_BACK      ,0      ,'\b'     ,'\b'     ,0x007f   },
  {VK_ESCAPE    ,0      ,0x001b   ,0x001b   ,0x001b   },
  {VK_RETURN    ,0      ,'\r'     ,'\r'     ,'\n'     },
  {VK_CANCEL    ,0      ,0x0003   ,0x0003   ,0x0003   },
  {0            ,0      ,0        ,0        ,0        }
};

static ALLOC_SECTION_LDATA VK_TO_WCHARS5 aVkToWch5[] = {
//                                   |         |  Shift  |  Ctrl   |  Ctl+Alt|S+Ctl+Alt|
//                                   |=========|=========|=========|=========|=========|
  {'1'          ,CAPLOK              ,WCH_DEAD ,'1'      ,WCH_NONE ,WCH_DEAD ,WCH_NONE },
  {0xff         ,0                   ,0x043C   ,WCH_NONE ,WCH_NONE ,0x1fee   ,WCH_NONE },
  {'2'          ,CAPLOK              ,'+'      ,'2'      ,WCH_NONE ,WCH_DEAD ,WCH_NONE },
  {0xff         ,0                   ,WCH_NONE ,WCH_NONE ,WCH_NONE ,0x1fed   ,WCH_NONE },
  {'3'          ,CAPLOK              ,WCH_LGTR ,'3'      ,WCH_NONE ,WCH_DEAD ,WCH_NONE },
  {0xff         ,0                   ,WCH_NONE ,WCH_NONE ,WCH_NONE ,0x03e9   ,WCH_NONE },
  {'4'          ,CAPLOK              ,'['      ,'4'      ,WCH_NONE ,WCH_DEAD ,WCH_NONE },
  {0xff         ,0                   ,WCH_NONE ,WCH_NONE ,WCH_NONE ,0x03e8   ,WCH_NONE },
  {'5'          ,CAPLOK              ,'('      ,'5'      ,WCH_NONE ,'{'      ,WCH_NONE },
  {'6'          ,CAPLOK              ,')'      ,'6'      ,WCH_NONE ,'}'      ,WCH_NONE },
  {'7'          ,CAPLOK              ,']'      ,'7'      ,WCH_NONE ,WCH_DEAD ,WCH_NONE },
  {0xff         ,0                   ,WCH_NONE ,WCH_NONE ,WCH_NONE ,0x03e7   ,WCH_NONE },
  {'8'          ,CAPLOK              ,'!'      ,'8'      ,WCH_NONE ,WCH_DEAD ,WCH_NONE },
  {0xff         ,0                   ,WCH_NONE ,WCH_NONE ,WCH_NONE ,0x03e5   ,WCH_NONE },
  {'9'          ,CAPLOK              ,0x03de   ,'9'      ,WCH_NONE ,WCH_DEAD ,WCH_NONE },
  {0xff         ,0                   ,WCH_NONE ,WCH_NONE ,WCH_NONE ,0x03e6   ,WCH_NONE },
  {'0'          ,CAPLOK              ,0x03e0   ,'0'      ,WCH_NONE ,WCH_DEAD ,WCH_NONE },
  {0xff         ,0                   ,WCH_NONE ,WCH_NONE ,WCH_NONE ,0x03e4   ,WCH_NONE },
  {VK_OEM_4     ,0                   ,WCH_DEAD ,'-'      ,WCH_NONE ,WCH_DEAD ,WCH_NONE },
  {0xff         ,0                   ,0x00a8   ,WCH_NONE ,WCH_NONE ,0x1fcf   ,WCH_NONE },
  {VK_OEM_PLUS  ,0                   ,WCH_DEAD ,'_'      ,WCH_NONE ,WCH_DEAD ,WCH_NONE },
  {0xff         ,0                   ,0x1fbe   ,WCH_NONE ,WCH_NONE ,0x1fdf   ,WCH_NONE },
  {'A'          ,CAPLOK | CAPLOKALTGR,0x03b1   ,0x0391   ,WCH_NONE ,WCH_NONE ,WCH_NONE },
  {'Z'          ,CAPLOK | CAPLOKALTGR,0x03b6   ,0x0396   ,WCH_NONE ,WCH_NONE ,WCH_NONE },
  {'E'          ,CAPLOK | CAPLOKALTGR,0x03b5   ,0x0395   ,WCH_NONE ,WCH_NONE ,WCH_NONE },
  {'R'          ,CAPLOK | CAPLOKALTGR,0x03c1   ,0x03a1   ,WCH_NONE ,WCH_NONE ,WCH_NONE },
  {'T'          ,CAPLOK | CAPLOKALTGR,0x03c4   ,0x03a4   ,WCH_NONE ,0x271D   ,WCH_NONE },
  {'Y'          ,CAPLOK | CAPLOKALTGR,0x03c5   ,0x03a5   ,WCH_NONE ,0x03D2   ,WCH_NONE },
  {'U'          ,CAPLOK | CAPLOKALTGR,0x03c8   ,0x03a8   ,WCH_NONE ,WCH_NONE ,WCH_NONE },
  {'I'          ,CAPLOK | CAPLOKALTGR,0x03b9   ,0x0399   ,WCH_NONE ,WCH_NONE ,WCH_NONE },
  {'O'          ,CAPLOK | CAPLOKALTGR,0x03bf   ,0x039f   ,WCH_NONE ,WCH_NONE ,WCH_NONE },
  {'P'          ,CAPLOK | CAPLOKALTGR,0x03c0   ,0x03a0   ,WCH_NONE ,0x03d6   ,WCH_NONE },
  {VK_OEM_6     ,0                   ,WCH_DEAD ,WCH_DEAD ,WCH_NONE ,WCH_DEAD ,WCH_NONE },
  {0xff         ,0                   ,0x1fbf   ,0x1fcd   ,WCH_NONE ,0x03eb   ,WCH_NONE },
  {VK_OEM_1     ,0                   ,WCH_DEAD ,WCH_DEAD ,WCH_NONE ,WCH_DEAD ,WCH_NONE },
  {0xff         ,0                   ,0x1ffe   ,0x1fdd   ,WCH_NONE ,0x03ea   ,WCH_NONE },
  {'Q'          ,CAPLOK | CAPLOKALTGR,0x03c7   ,0x03a7   ,WCH_NONE ,0x2043   ,WCH_NONE },
  {'S'          ,CAPLOK | CAPLOKALTGR,0x03c3   ,0x03a3   ,WCH_NONE ,0x2041   ,WCH_NONE },
  {'D'          ,CAPLOK | CAPLOKALTGR,0x03b4   ,0x0394   ,WCH_NONE ,0x2042   ,WCH_NONE },
  {'F'          ,CAPLOK | CAPLOKALTGR,0x03c6   ,0x03a6   ,WCH_NONE ,0x03d5   ,WCH_NONE },
  {'G'          ,CAPLOK | CAPLOKALTGR,0x03b3   ,0x0393   ,WCH_NONE ,0x2045   ,WCH_NONE },
  {'H'          ,CAPLOK | CAPLOKALTGR,0x03b7   ,0x0397   ,WCH_NONE ,0x03E0   ,WCH_NONE },
  {'J'          ,CAPLOK | CAPLOKALTGR,0x03b8   ,0x0398   ,WCH_NONE ,0x03d1   ,WCH_NONE },
  {'K'          ,CAPLOK | CAPLOKALTGR,0x03ba   ,0x039a   ,WCH_NONE ,WCH_NONE ,WCH_NONE },
  {'L'          ,CAPLOK | CAPLOKALTGR,0x03bb   ,0x039b   ,WCH_NONE ,0x2044   ,WCH_NONE },
  {'M'          ,CAPLOK | CAPLOKALTGR,0x03bc   ,0x039c   ,WCH_NONE ,0x0400   ,WCH_NONE },
  {VK_OEM_3     ,0                   ,WCH_DEAD ,WCH_DEAD ,WCH_NONE ,WCH_DEAD ,WCH_DEAD },
  {0xff         ,0                   ,0x1ffd   ,0x1fce   ,WCH_NONE ,0x03e2   ,0x02c9   },
  {VK_OEM_7     ,CAPLOK              ,0x03da   ,0x271d   ,WCH_NONE ,WCH_DEAD ,WCH_NONE },
  {0xff         ,0                   ,WCH_NONE ,WCH_NONE ,WCH_NONE ,0x1fc1   ,WCH_NONE },
  {VK_OEM_5     ,0                   ,WCH_DEAD ,WCH_DEAD ,WCH_NONE ,WCH_DEAD ,WCH_DEAD },
  {0xff         ,0                   ,0x1fef   ,0x1fde   ,WCH_NONE ,0x03e3   ,0x02d8   },
  {'W'          ,CAPLOK | CAPLOKALTGR,0x03c9   ,0x03a9   ,WCH_NONE ,WCH_NONE ,WCH_NONE },
  {'X'          ,CAPLOK | CAPLOKALTGR,0x03be   ,0x039e   ,WCH_NONE ,0x03DE   ,WCH_NONE },
  {'C'          ,CAPLOK | CAPLOKALTGR,0x03c2   ,0x0400   ,WCH_NONE ,0x03DA   ,WCH_NONE },
  {'V'          ,CAPLOK | CAPLOKALTGR,0x03dc   ,0x0401   ,WCH_NONE ,0x03DC   ,WCH_NONE },
  {'B'          ,CAPLOK | CAPLOKALTGR,0x03b2   ,0x0392   ,WCH_NONE ,0x03d0   ,WCH_NONE },
  {'N'          ,CAPLOK | CAPLOKALTGR,0x03bd   ,0x039d   ,WCH_NONE ,0x0401   ,WCH_NONE },
  {VK_OEM_COMMA ,CAPLOK | CAPLOKALTGR,','      ,0x037e   ,WCH_NONE ,0x1FFF   ,WCH_NONE },
  {VK_OEM_PERIOD,CAPLOK | CAPLOKALTGR,0x0387   ,'.'      ,WCH_NONE ,0x0374   ,WCH_NONE },
  {VK_OEM_2     ,CAPLOK | CAPLOKALTGR,':'      ,'/'      ,WCH_NONE ,0x0375   ,WCH_NONE },
  {VK_OEM_8     ,0                   ,WCH_DEAD ,0x1fff   ,WCH_NONE ,WCH_DEAD ,WCH_NONE },
  {0xff         ,0                   ,0x1fc0   ,WCH_NONE ,WCH_NONE ,0x0342   ,WCH_NONE },
  {VK_SPACE     ,0                   ,' '      ,' '      ,WCH_NONE ,WCH_NONE ,WCH_NONE },
  {VK_OEM_102   ,CAPLOK | CAPLOKALTGR,0x2039   ,0x203a   ,WCH_NONE ,'\\'     ,WCH_NONE },
  {VK_DECIMAL   ,0                   ,','      ,','      ,WCH_NONE ,WCH_NONE ,WCH_NONE },
  {0            ,0                   ,0        ,0        ,0        ,0        ,0        }
};

// Put this last so that VkKeyScan interprets number characters
// as coming from the main section of the kbd (aVkToWch2 and
// aVkToWch5) before considering the numpad (aVkToWch1).

static ALLOC_SECTION_LDATA VK_TO_WCHARS1 aVkToWch1[] = {
    { VK_NUMPAD0   , 0      ,  '0'   },
    { VK_NUMPAD1   , 0      ,  '1'   },
    { VK_NUMPAD2   , 0      ,  '2'   },
    { VK_NUMPAD3   , 0      ,  '3'   },
    { VK_NUMPAD4   , 0      ,  '4'   },
    { VK_NUMPAD5   , 0      ,  '5'   },
    { VK_NUMPAD6   , 0      ,  '6'   },
    { VK_NUMPAD7   , 0      ,  '7'   },
    { VK_NUMPAD8   , 0      ,  '8'   },
    { VK_NUMPAD9   , 0      ,  '9'   },
    { 0            , 0      ,  '\0'  }
};

static ALLOC_SECTION_LDATA VK_TO_WCHAR_TABLE aVkToWcharTable[] = {
    {  (PVK_TO_WCHARS1)aVkToWch3, 3, sizeof(aVkToWch3[0]) },
    {  (PVK_TO_WCHARS1)aVkToWch5, 5, sizeof(aVkToWch5[0]) },
    {  (PVK_TO_WCHARS1)aVkToWch2, 2, sizeof(aVkToWch2[0]) },
    {  (PVK_TO_WCHARS1)aVkToWch1, 1, sizeof(aVkToWch1[0]) },
    {                       NULL, 0, 0                    },
};

/***************************************************************************\
* aKeyNames[], aKeyNamesExt[]  - Virtual Scancode to Key Name tables
*
* Table attributes: Ordered Scan (by scancode), null-terminated
*
* Only the names of Extended, NumPad, Dead and Non-Printable keys are here.
* (Keys producing printable characters are named by that character)
\***************************************************************************/

static ALLOC_SECTION_LDATA VSC_LPWSTR aKeyNames[] = {
    0x01,    L"Esc",
    0x0e,    L"Backspace",
    0x0f,    L"Tab",
    0x1c,    L"Enter",
    0x1d,    L"Ctrl",
    0x2a,    L"Shift",
    0x36,    L"Right Shift",
    0x37,    L"Num *",
    0x38,    L"Alt",
    0x39,    L"Space",
    0x3a,    L"Caps Lock",
    0x3b,    L"F1",
    0x3c,    L"F2",
    0x3d,    L"F3",
    0x3e,    L"F4",
    0x3f,    L"F5",
    0x40,    L"F6",
    0x41,    L"F7",
    0x42,    L"F8",
    0x43,    L"F9",
    0x44,    L"F10",
    0x45,    L"Pause",
    0x46,    L"Scroll Lock",
    0x47,    L"Num 7",
    0x48,    L"Num 8",
    0x49,    L"Num 9",
    0x4a,    L"Num -",
    0x4b,    L"Num 4",
    0x4c,    L"Num 5",
    0x4d,    L"Num 6",
    0x4e,    L"Num +",
    0x4f,    L"Num 1",
    0x50,    L"Num 2",
    0x51,    L"Num 3",
    0x52,    L"Num 0",
    0x53,    L"Num Del",
    0x54,    L"Sys Req",
    0x57,    L"F11",
    0x58,    L"F12",
    0x7c,    L"F13",
    0x7d,    L"F14",
    0x7e,    L"F15",
    0x7f,    L"F16",
    0x80,    L"F17",
    0x81,    L"F18",
    0x82,    L"F19",
    0x83,    L"F20",
    0x84,    L"F21",
    0x85,    L"F22",
    0x86,    L"F23",
    0x87,    L"F24",
    0   ,    NULL
};

static ALLOC_SECTION_LDATA VSC_LPWSTR aKeyNamesExt[] = {
    0x1c,    L"Num Enter",
    0x1d,    L"Right Ctrl",
    0x35,    L"Num /",
    0x37,    L"Prnt Scrn",
    0x38,    L"Right Alt",
    0x45,    L"Num Lock",
    0x46,    L"Break",
    0x47,    L"Home",
    0x48,    L"Up",
    0x49,    L"Page Up",
    0x4b,    L"Left",
    0x4d,    L"Right",
    0x4f,    L"End",
    0x50,    L"Down",
    0x51,    L"Page Down",
    0x52,    L"Insert",
    0x53,    L"Delete",
    0x54,    L"<00>",
    0x56,    L"Help",
    0x5b,    L"Left Windows",
    0x5c,    L"Right Windows",
    0x5d,    L"Application",
    0   ,    NULL
};

static ALLOC_SECTION_LDATA DEADKEY_LPWSTR aKeyNamesDead[] = {
    L"\x1fee"	L"GREEK DIALYTIKA AND OXIA",
    L"\x1fed"	L"GREEK DIALYTIKA AND VARIA",
    L"\x03e9"	L"COPTIC SMALL LETTER HORI",
    L"\x03e8"	L"COPTIC CAPITAL LETTER HORI",
    L"\x03e7"	L"COPTIC SMALL LETTER KHEI",
    L"\x03e5"	L"COPTIC SMALL LETTER FEI",
    L"\x03e6"	L"COPTIC CAPITAL LETTER KHEI",
    L"\x03e4"	L"COPTIC CAPITAL LETTER FEI",
    L"\x1fcf"	L"GREEK PSILI AND PERISPOMENI",
    L"\x1fdf"	L"GREEK DASIA AND PERISPOMENI",
    L"\x1fbf"	L"GREEK PSILI",
    L"\x1fcd"	L"GREEK PSILI AND VARIA",
    L"\x03eb"	L"COPTIC SMALL LETTER GANGIA",
    L"\x1ffe"	L"GREEK DASIA",
    L"\x1fdd"	L"GREEK DASIA AND VARIA",
    L"\x03ea"	L"COPTIC CAPITAL LETTER GANGIA",
    L"\x1ffd"	L"GREEK OXIA",
    L"\x1fce"	L"GREEK PSILI AND OXIA",
    L"\x03e2"	L"COPTIC CAPITAL LETTER SHEI",
    L"\x02c9"	L"MODIFIER LETTER MACRON (Mandarin Chinese first tone)",
    L"\x1fbe"	L"GREEK PROSGEGRAMMENI",
    L"\x00a8"	L"DIAERESIS",
    L"\x1fc1"	L"GREEK DIALYTIKA AND PERISPOMENI",
    L"\x1fef"	L"GREEK VARIA",
    L"\x1fde"	L"GREEK DASIA AND OXIA",
    L"\x03e3"	L"COPTIC SMALL LETTER SHEI",
    L"\x02d8"	L"BREVE",
    L"\x1fc0"	L"GREEK PERISPOMENI",
    L"\x0342"	L"COMBINING GREEK PERISPOMENI",
    NULL
};

static ALLOC_SECTION_LDATA DEADKEY aDeadKey[] = {
	/* trma accent aigu */
    DEADTRANS( L' '   , 0x1fee , 0x1fee , 0x0000),
    DEADTRANS( 0x03b9 , 0x1fee , 0x1fd3 , 0x0000),
    DEADTRANS( 0x0399 , 0x1fee , 0x03fe , 0x0000),
    DEADTRANS( 0x03c5 , 0x1fee , 0x1fe3 , 0x0000),
    DEADTRANS( 0x03a5 , 0x1fee , 0x03fc , 0x0000),

	/* trma accent grave */
    DEADTRANS( L' '   , 0x1fed , 0x1fed , 0x0000),
    DEADTRANS( 0x03b9 , 0x1fed , 0x1fd2 , 0x0000),
    DEADTRANS( 0x0399 , 0x1fed , 0x1fdc , 0x0000),
    DEADTRANS( 0x03c5 , 0x1fed , 0x1fe2 , 0x0000),
    DEADTRANS( 0x03a5 , 0x1fed , 0x03fb , 0x0000),

	/* esprit doux circonflexe iota souscrit */
    DEADTRANS( L' '   , 0x03e9 , 0x03e9 , 0x0000),
    DEADTRANS( 0x03b1 , 0x03e9 , 0x1f86 , 0x0000),
    DEADTRANS( 0x0391 , 0x03e9 , 0x1f8e , 0x0000),
    DEADTRANS( 0x03b7 , 0x03e9 , 0x1f96 , 0x0000),
    DEADTRANS( 0x0397 , 0x03e9 , 0x1f9e , 0x0000),
    DEADTRANS( 0x03c9 , 0x03e9 , 0x1fa6 , 0x0000),
    DEADTRANS( 0x03a9 , 0x03e9 , 0x1fae , 0x0000),

	/* esprit rude circonflexe iota souscrit */
    DEADTRANS( L' '   , 0x03e8 , 0x03e8 , 0x0000),
    DEADTRANS( 0x03b1 , 0x03e8 , 0x1f87 , 0x0000),
    DEADTRANS( 0x0391 , 0x03e8 , 0x1f8f , 0x0000),
    DEADTRANS( 0x03b7 , 0x03e8 , 0x1f97 , 0x0000),
    DEADTRANS( 0x0397 , 0x03e8 , 0x1f9f , 0x0000),
    DEADTRANS( 0x03c9 , 0x03e8 , 0x1fa7 , 0x0000),
    DEADTRANS( 0x03a9 , 0x03e8 , 0x1faf , 0x0000),

	/* esprit doux accent aigu iota souscrit */
    DEADTRANS( L' '   , 0x03e7 , 0x03e7 , 0x0000),
    DEADTRANS( 0x03b1 , 0x03e7 , 0x1f84 , 0x0000),
    DEADTRANS( 0x0391 , 0x03e7 , 0x1f8c , 0x0000),
    DEADTRANS( 0x03b7 , 0x03e7 , 0x1f94 , 0x0000),
    DEADTRANS( 0x0397 , 0x03e7 , 0x1f9c , 0x0000),
    DEADTRANS( 0x03c9 , 0x03e7 , 0x1fa4 , 0x0000),
    DEADTRANS( 0x03a9 , 0x03e7 , 0x1fac , 0x0000),

	/* esprit rude accent aigu iota souscrit */
    DEADTRANS( L' '   , 0x03e5 , 0x03e5 , 0x0000),
    DEADTRANS( 0x03b1 , 0x03e5 , 0x1f85 , 0x0000),
    DEADTRANS( 0x0391 , 0x03e5 , 0x1f8d , 0x0000),
    DEADTRANS( 0x03b7 , 0x03e5 , 0x1f95 , 0x0000),
    DEADTRANS( 0x0397 , 0x03e5 , 0x1f9d , 0x0000),
    DEADTRANS( 0x03c9 , 0x03e5 , 0x1fa5 , 0x0000),
    DEADTRANS( 0x03a9 , 0x03e5 , 0x1fad , 0x0000),

	/* esprit doux accent grave iota souscrit */
    DEADTRANS( L' '   , 0x03e6 , 0x03e6 , 0x0000),
    DEADTRANS( 0x03b1 , 0x03e6 , 0x1f82 , 0x0000),
    DEADTRANS( 0x0391 , 0x03e6 , 0x1f8a , 0x0000),
    DEADTRANS( 0x03b7 , 0x03e6 , 0x1f92 , 0x0000),
    DEADTRANS( 0x0397 , 0x03e6 , 0x1f9a , 0x0000),
    DEADTRANS( 0x03c9 , 0x03e6 , 0x1fa2 , 0x0000),
    DEADTRANS( 0x03a9 , 0x03e6 , 0x1faa , 0x0000),

	/* esprit rude accent grave iota souscrit */
    DEADTRANS( L' '   , 0x03e4 , 0x03e4 , 0x0000),
    DEADTRANS( 0x03b1 , 0x03e4 , 0x1f83 , 0x0000),
    DEADTRANS( 0x0391 , 0x03e4 , 0x1f8b , 0x0000),
    DEADTRANS( 0x03b7 , 0x03e4 , 0x1f93 , 0x0000),
    DEADTRANS( 0x0397 , 0x03e4 , 0x1f9b , 0x0000),
    DEADTRANS( 0x03c9 , 0x03e4 , 0x1fa3 , 0x0000),
    DEADTRANS( 0x03a9 , 0x03e4 , 0x1fab , 0x0000),

	/* esprit doux circonflexe */
    DEADTRANS( L' '   , 0x1fcf , 0x1fcf , 0x0000),
    DEADTRANS( 0x03b1 , 0x1fcf , 0x1f06 , 0x0000),
    DEADTRANS( 0x1fb3 , 0x1fcf , 0x1f86 , 0x0000),
    DEADTRANS( 0x0391 , 0x1fcf , 0x1f0e , 0x0000),
    DEADTRANS( 0x1fbc , 0x1fcf , 0x1f8e , 0x0000),
    DEADTRANS( 0x03b7 , 0x1fcf , 0x1f26 , 0x0000),
    DEADTRANS( 0x1fc3 , 0x1fcf , 0x1f96 , 0x0000),
    DEADTRANS( 0x0397 , 0x1fcf , 0x1f2e , 0x0000),
    DEADTRANS( 0x1fcc , 0x1fcf , 0x1f9e , 0x0000),
    DEADTRANS( 0x03b9 , 0x1fcf , 0x1f36 , 0x0000),
    DEADTRANS( 0x0399 , 0x1fcf , 0x1f3e , 0x0000),
    DEADTRANS( 0x03c5 , 0x1fcf , 0x1f56 , 0x0000),
    DEADTRANS( 0x03a5 , 0x1fcf , 0x1f5e , 0x0000),
    DEADTRANS( 0x03c9 , 0x1fcf , 0x1f66 , 0x0000),
    DEADTRANS( 0x1ff3 , 0x1fcf , 0x1fa6 , 0x0000),
    DEADTRANS( 0x03a9 , 0x1fcf , 0x1f6e , 0x0000),
    DEADTRANS( 0x1ffc , 0x1fcf , 0x1fae , 0x0000),
    DEADTRANS( 0x1fbe , 0x1fcf , 0x03e9 , DKF_DEAD), /* esprit doux/circonflexe + iota souscrit */

	/* esprit rude circonflexe */
    DEADTRANS( L' '   , 0x1fdf , 0x1fdf , 0x0000),
    DEADTRANS( 0x03b1 , 0x1fdf , 0x1f07 , 0x0000),
    DEADTRANS( 0x1fb3 , 0x1fdf , 0x1f87 , 0x0000),
    DEADTRANS( 0x0391 , 0x1fdf , 0x1f0f , 0x0000),
    DEADTRANS( 0x1fbc , 0x1fdf , 0x1f8f , 0x0000),
    DEADTRANS( 0x03b7 , 0x1fdf , 0x1f27 , 0x0000),
    DEADTRANS( 0x1fc3 , 0x1fdf , 0x1f97 , 0x0000),
    DEADTRANS( 0x0397 , 0x1fdf , 0x1f2f , 0x0000),
    DEADTRANS( 0x1fcc , 0x1fdf , 0x1f9f , 0x0000),
    DEADTRANS( 0x03b9 , 0x1fdf , 0x1f37 , 0x0000),
    DEADTRANS( 0x0399 , 0x1fdf , 0x1f3f , 0x0000),
    DEADTRANS( 0x03c5 , 0x1fdf , 0x1f57 , 0x0000),
    DEADTRANS( 0x03a5 , 0x1fdf , 0x1f5f , 0x0000),
    DEADTRANS( 0x03c9 , 0x1fdf , 0x1f67 , 0x0000),
    DEADTRANS( 0x1ff3 , 0x1fdf , 0x1fa7 , 0x0000),
    DEADTRANS( 0x03a9 , 0x1fdf , 0x1f6f , 0x0000),
    DEADTRANS( 0x1ffc , 0x1fdf , 0x1faf , 0x0000),
    DEADTRANS( 0x1fbe , 0x1fdf , 0x03e8 , DKF_DEAD),	/* esprit rude/circonflexe + iota souscrit */

	/* esprit doux */
    DEADTRANS( 0x03b1 , 0x1fbf , 0x1f00 , 0x0000),
    DEADTRANS( 0x1fb6 , 0x1fbf , 0x1f06 , 0x0000),
    DEADTRANS( 0x1fb3 , 0x1fbf , 0x1f80 , 0x0000),
    DEADTRANS( 0x0391 , 0x1fbf , 0x1f08 , 0x0000),
    DEADTRANS( 0x03ec , 0x1fbf , 0x1f0e , 0x0000),
    DEADTRANS( 0x1fbc , 0x1fbf , 0x1f88 , 0x0000),
    DEADTRANS( 0x03b5 , 0x1fbf , 0x1f10 , 0x0000),
    DEADTRANS( 0x0395 , 0x1fbf , 0x1f18 , 0x0000),
    DEADTRANS( 0x03b7 , 0x1fbf , 0x1f20 , 0x0000),
    DEADTRANS( 0x1fc6 , 0x1fbf , 0x1f26 , 0x0000),
    DEADTRANS( 0x1fc3 , 0x1fbf , 0x1f90 , 0x0000),
    DEADTRANS( 0x1f00 , 0x1fbf , 0x03b1 , 0x0000),
    DEADTRANS( 0x1f08 , 0x1fbf , 0x0391 , 0x0000),
    DEADTRANS( 0x1f10 , 0x1fbf , 0x03b5 , 0x0000),
    DEADTRANS( 0x1f18 , 0x1fbf , 0x0395 , 0x0000),
    DEADTRANS( 0x1f20 , 0x1fbf , 0x03b7 , 0x0000),
    DEADTRANS( 0x0397 , 0x1fbf , 0x1f28 , 0x0000),
    DEADTRANS( 0x1f28 , 0x1fbf , 0x0397 , 0x0000),
    DEADTRANS( 0x03f1 , 0x1fbf , 0x1f2e , 0x0000),
    DEADTRANS( 0x1fcc , 0x1fbf , 0x1f98 , 0x0000),
    DEADTRANS( 0x03b9 , 0x1fbf , 0x1f30 , 0x0000),
    DEADTRANS( 0x1f30 , 0x1fbf , 0x03b9 , 0x0000),
    DEADTRANS( 0x1fd6 , 0x1fbf , 0x1f36 , 0x0000),
    DEADTRANS( 0x0399 , 0x1fbf , 0x1f38 , 0x0000),
    DEADTRANS( 0x1f38 , 0x1fbf , 0x0399 , 0x0000),
    DEADTRANS( 0x03fa , 0x1fbf , 0x1f3e , 0x0000),
    DEADTRANS( 0x03bf , 0x1fbf , 0x1f40 , 0x0000),
    DEADTRANS( 0x1f40 , 0x1fbf , 0x03bf , 0x0000),
    DEADTRANS( 0x039f , 0x1fbf , 0x1f48 , 0x0000),
    DEADTRANS( 0x1f48 , 0x1fbf , 0x039f , 0x0000),
    DEADTRANS( 0x03c1 , 0x1fbf , 0x1fe4 , 0x0000),
    DEADTRANS( 0x03a1 , 0x1fbf , 0x03f0 , 0x0000),
    DEADTRANS( 0x03c5 , 0x1fbf , 0x1f50 , 0x0000),
    DEADTRANS( 0x1f50 , 0x1fbf , 0x03c5 , 0x0000),
    DEADTRANS( 0x1fe6 , 0x1fbf , 0x1f56 , 0x0000),
    DEADTRANS( 0x03a5 , 0x1fbf , 0x1f58 , 0x0000),
    DEADTRANS( 0x1f58 , 0x1fbf , 0x03a5 , 0x0000),
    DEADTRANS( 0x03f9 , 0x1fbf , 0x1f5e , 0x0000),
    DEADTRANS( 0x03c9 , 0x1fbf , 0x1f60 , 0x0000),
    DEADTRANS( 0x1f60 , 0x1fbf , 0x03c9 , 0x0000),
    DEADTRANS( 0x1ff6 , 0x1fbf , 0x1f66 , 0x0000),
    DEADTRANS( 0x1ff3 , 0x1fbf , 0x1fa0 , 0x0000),
    DEADTRANS( 0x03a9 , 0x1fbf , 0x1f68 , 0x0000),
    DEADTRANS( 0x1f68 , 0x1fbf , 0x03a9 , 0x0000),
    DEADTRANS( 0x03f5 , 0x1fbf , 0x1f6e , 0x0000),
    DEADTRANS( 0x1ffc , 0x1fbf , 0x1fa8 , 0x0000),
    DEADTRANS( L' '   , 0x1fbf , 0x1fbf , 0x0000),
    DEADTRANS( 0x1ffd , 0x1fbf , 0x1fce , DKF_DEAD), /* esprit doux + accent aigu */
    DEADTRANS( 0x1fef , 0x1fbf , 0x1fcd , DKF_DEAD), /* esprit doux + accent grave */
    DEADTRANS( 0x1fc0 , 0x1fbf , 0x1fcf , DKF_DEAD), /* esprit doux + accent circonflexe */
    DEADTRANS( 0x1fbe , 0x1fbf , 0x03eb , DKF_DEAD), /* esprit doux + iota souscrit */
    DEADTRANS( 0x03e2 , 0x1fbf , 0x03e7 , DKF_DEAD), /* esprit doux + accent aigu/iota souscrit */
    DEADTRANS( 0x03e3 , 0x1fbf , 0x03e6 , DKF_DEAD), /* esprit doux + accent grave/iota souscrit */
    DEADTRANS( 0x0342 , 0x1fbf , 0x03e9 , DKF_DEAD), /* esprit doux + accent circonflexe/iota souscrit */

	/* esprit doux/accent grave */
    DEADTRANS( L' '   , 0x1fcd , 0x1fcd , 0x0000),
    DEADTRANS( 0x03b1 , 0x1fcd , 0x1f02 , 0x0000),
    DEADTRANS( 0x1fb3 , 0x1fcd , 0x1f82 , 0x0000),
    DEADTRANS( 0x0391 , 0x1fcd , 0x1f0a , 0x0000),
    DEADTRANS( 0x1fbc , 0x1fcd , 0x1f8a , 0x0000),
    DEADTRANS( 0x03b5 , 0x1fcd , 0x1f12 , 0x0000),
    DEADTRANS( 0x0395 , 0x1fcd , 0x1f1a , 0x0000),
    DEADTRANS( 0x03b7 , 0x1fcd , 0x1f22 , 0x0000),
    DEADTRANS( 0x1fc3 , 0x1fcd , 0x1f92 , 0x0000),
    DEADTRANS( 0x0397 , 0x1fcd , 0x1f2a , 0x0000),
    DEADTRANS( 0x1fcc , 0x1fcd , 0x1f9a , 0x0000),
    DEADTRANS( 0x03b9 , 0x1fcd , 0x1f32 , 0x0000),
    DEADTRANS( 0x0399 , 0x1fcd , 0x1f3a , 0x0000),
    DEADTRANS( 0x03bf , 0x1fcd , 0x1f42 , 0x0000),
    DEADTRANS( 0x039f , 0x1fcd , 0x1f4a , 0x0000),
    DEADTRANS( 0x03c5 , 0x1fcd , 0x1f52 , 0x0000),
    DEADTRANS( 0x03a5 , 0x1fcd , 0x1f5a , 0x0000),
    DEADTRANS( 0x03c9 , 0x1fcd , 0x1f62 , 0x0000),
    DEADTRANS( 0x1ff3 , 0x1fcd , 0x1fa2 , 0x0000),
    DEADTRANS( 0x03a9 , 0x1fcd , 0x1f6a , 0x0000),
    DEADTRANS( 0x1ffc , 0x1fcd , 0x1faa , 0x0000),
    DEADTRANS( 0x1fbe , 0x1fcd , 0x03e6 , DKF_DEAD), /* esprit doux/accent grave + iota souscrit */

	/* esprit doux/iota souscrit */
    DEADTRANS( L' '   , 0x03eb , 0x03eb , 0x0000),
    DEADTRANS( 0x03b1 , 0x03eb , 0x1f80 , 0x0000),
    DEADTRANS( 0x0391 , 0x03eb , 0x1f88 , 0x0000),
    DEADTRANS( 0x03b7 , 0x03eb , 0x1f90 , 0x0000),
    DEADTRANS( 0x0397 , 0x03eb , 0x1f98 , 0x0000),
    DEADTRANS( 0x03c9 , 0x03eb , 0x1fa0 , 0x0000),
    DEADTRANS( 0x03a9 , 0x03eb , 0x1fa8 , 0x0000),
    DEADTRANS( 0x1ffd , 0x03eb , 0x03e7 , DKF_DEAD), /* esprit doux/iota souscrit + accent aigu */
    DEADTRANS( 0x1fef , 0x03eb , 0x03e6 , DKF_DEAD), /* esprit doux/iota souscrit + accent grave */
    DEADTRANS( 0x1fc0 , 0x03eb , 0x03e9 , DKF_DEAD), /* esprit doux/iota souscrit + circonflexe */

	/* esprit rude */
    DEADTRANS( 0x03b1 , 0x1ffe , 0x1f01 , 0x0000),
    DEADTRANS( L' '   , 0x1ffe , 0x1ffe , 0x0000),
    DEADTRANS( 0x1f01 , 0x1ffe , 0x03b1 , 0x0000),
    DEADTRANS( 0x1fb6 , 0x1ffe , 0x1f07 , 0x0000),
    DEADTRANS( 0x1fb3 , 0x1ffe , 0x1f81 , 0x0000),
    DEADTRANS( 0x0391 , 0x1ffe , 0x1f09 , 0x0000),
    DEADTRANS( 0x1f09 , 0x1ffe , 0x0391 , 0x0000),
    DEADTRANS( 0x03ec , 0x1ffe , 0x1f0f , 0x0000),
    DEADTRANS( 0x1fbc , 0x1ffe , 0x1f89 , 0x0000),
    DEADTRANS( 0x03b5 , 0x1ffe , 0x1f11 , 0x0000),
    DEADTRANS( 0x1f11 , 0x1ffe , 0x03b5 , 0x0000),
    DEADTRANS( 0x0395 , 0x1ffe , 0x1f19 , 0x0000),
    DEADTRANS( 0x1f19 , 0x1ffe , 0x0395 , 0x0000),
    DEADTRANS( 0x03b7 , 0x1ffe , 0x1f21 , 0x0000),
    DEADTRANS( 0x1f21 , 0x1ffe , 0x03b7 , 0x0000),
    DEADTRANS( 0x1fc6 , 0x1ffe , 0x1f27 , 0x0000),
    DEADTRANS( 0x1fc3 , 0x1ffe , 0x1f91 , 0x0000),
    DEADTRANS( 0x0397 , 0x1ffe , 0x1f29 , 0x0000),
    DEADTRANS( 0x1f29 , 0x1ffe , 0x0397 , 0x0000),
    DEADTRANS( 0x03f1 , 0x1ffe , 0x1f2f , 0x0000),
    DEADTRANS( 0x1fcc , 0x1ffe , 0x1f99 , 0x0000),
    DEADTRANS( 0x03b9 , 0x1ffe , 0x1f31 , 0x0000),
    DEADTRANS( 0x1f31 , 0x1ffe , 0x03b9 , 0x0000),
    DEADTRANS( 0x1fd6 , 0x1ffe , 0x1f37 , 0x0000),
    DEADTRANS( 0x0399 , 0x1ffe , 0x1f39 , 0x0000),
    DEADTRANS( 0x1f39 , 0x1ffe , 0x0399 , 0x0000),
    DEADTRANS( 0x03fa , 0x1ffe , 0x1f3f , 0x0000),
    DEADTRANS( 0x03bf , 0x1ffe , 0x1f41 , 0x0000),
    DEADTRANS( 0x1f41 , 0x1ffe , 0x03bf , 0x0000),
    DEADTRANS( 0x039f , 0x1ffe , 0x1f49 , 0x0000),
    DEADTRANS( 0x1f49 , 0x1ffe , 0x039f , 0x0000),
    DEADTRANS( 0x03c1 , 0x1ffe , 0x1fe5 , 0x0000),
    DEADTRANS( 0x1fe5 , 0x1ffe , 0x03c1 , 0x0000),
    DEADTRANS( 0x03a1 , 0x1ffe , 0x1fec , 0x0000),
    DEADTRANS( 0x1fec , 0x1ffe , 0x03a1 , 0x0000),
    DEADTRANS( 0x03c5 , 0x1ffe , 0x1f51 , 0x0000),
    DEADTRANS( 0x1f51 , 0x1ffe , 0x03c5 , 0x0000),
    DEADTRANS( 0x1fe6 , 0x1ffe , 0x1f57 , 0x0000),
    DEADTRANS( 0x03a5 , 0x1ffe , 0x1f59 , 0x0000),
    DEADTRANS( 0x1f59 , 0x1ffe , 0x03a5 , 0x0000),
    DEADTRANS( 0x03f9 , 0x1ffe , 0x1f5f , 0x0000),
    DEADTRANS( 0x03c9 , 0x1ffe , 0x1f61 , 0x0000),
    DEADTRANS( 0x1f61 , 0x1ffe , 0x03c9 , 0x0000),
    DEADTRANS( 0x1ff6 , 0x1ffe , 0x1f67 , 0x0000),
    DEADTRANS( 0x1ff3 , 0x1ffe , 0x1fa1 , 0x0000),
    DEADTRANS( 0x03a9 , 0x1ffe , 0x1f69 , 0x0000),
    DEADTRANS( 0x1f69 , 0x1ffe , 0x03a9 , 0x0000),
    DEADTRANS( 0x03f5 , 0x1ffe , 0x1f6f , 0x0000),
    DEADTRANS( 0x1ffc , 0x1ffe , 0x1fa9 , 0x0000),
    DEADTRANS( 0x1ffd , 0x1ffe , 0x1fde , DKF_DEAD), /* esprit rude + accent aigu */
    DEADTRANS( 0x1fef , 0x1ffe , 0x1fdd , DKF_DEAD), /* esprit rude + accent grave */
    DEADTRANS( 0x1fc0 , 0x1ffe , 0x1fdf , DKF_DEAD), /* esprit rude + accent circonflexe */
    DEADTRANS( 0x1fbe , 0x1ffe , 0x03ea , DKF_DEAD), /* esprit rude + iota souscrit */
    DEADTRANS( 0x03e2 , 0x1ffe , 0x03e5 , DKF_DEAD), /* esprit rude + accent aigu/iota souscrit */
    DEADTRANS( 0x03e3 , 0x1ffe , 0x03e4 , DKF_DEAD), /* esprit rude + accent grave/iota souscrit */
    DEADTRANS( 0x0342 , 0x1ffe , 0x03e8 , DKF_DEAD), /* esprit rude + accent circonflexe/iota souscrit */

	/* esprit rude/accent grave */
    DEADTRANS( L' '   , 0x1fdd , 0x1fdd , 0x0000),
    DEADTRANS( 0x03b1 , 0x1fdd , 0x1f03 , 0x0000),
    DEADTRANS( 0x1fb3 , 0x1fdd , 0x1f83 , 0x0000),
    DEADTRANS( 0x0391 , 0x1fdd , 0x1f0b , 0x0000),
    DEADTRANS( 0x1fbc , 0x1fdd , 0x1f8b , 0x0000),
    DEADTRANS( 0x03b5 , 0x1fdd , 0x1f13 , 0x0000),
    DEADTRANS( 0x0395 , 0x1fdd , 0x1f1b , 0x0000),
    DEADTRANS( 0x03b7 , 0x1fdd , 0x1f23 , 0x0000),
    DEADTRANS( 0x1fc3 , 0x1fdd , 0x1f93 , 0x0000),
    DEADTRANS( 0x0397 , 0x1fdd , 0x1f2b , 0x0000),
    DEADTRANS( 0x1fcc , 0x1fdd , 0x1f9b , 0x0000),
    DEADTRANS( 0x03b9 , 0x1fdd , 0x1f33 , 0x0000),
    DEADTRANS( 0x0399 , 0x1fdd , 0x1f3b , 0x0000),
    DEADTRANS( 0x03bf , 0x1fdd , 0x1f43 , 0x0000),
    DEADTRANS( 0x039f , 0x1fdd , 0x1f4b , 0x0000),
    DEADTRANS( 0x03c5 , 0x1fdd , 0x1f53 , 0x0000),
    DEADTRANS( 0x03a5 , 0x1fdd , 0x1f5b , 0x0000),
    DEADTRANS( 0x03c9 , 0x1fdd , 0x1f63 , 0x0000),
    DEADTRANS( 0x1ff3 , 0x1fdd , 0x1fa3 , 0x0000),
    DEADTRANS( 0x03a9 , 0x1fdd , 0x1f6b , 0x0000),
    DEADTRANS( 0x1ffc , 0x1fdd , 0x1fab , 0x0000),
    DEADTRANS( 0x1fbe , 0x1fdd , 0x03e4 , DKF_DEAD), /* esprit rude/accent grave + iota souscrit */

	/* esprit rude/iota souscrit */
    DEADTRANS( L' '   , 0x03ea , 0x03ea , 0x0000),
    DEADTRANS( 0x03b1 , 0x03ea , 0x1f81 , 0x0000),
    DEADTRANS( 0x0391 , 0x03ea , 0x1f89 , 0x0000),
    DEADTRANS( 0x03b7 , 0x03ea , 0x1f91 , 0x0000),
    DEADTRANS( 0x0397 , 0x03ea , 0x1f99 , 0x0000),
    DEADTRANS( 0x03c9 , 0x03ea , 0x1fa1 , 0x0000),
    DEADTRANS( 0x03a9 , 0x03ea , 0x1fa9 , 0x0000),
    DEADTRANS( 0x1ffd , 0x03ea , 0x03e5 , DKF_DEAD), /* esprit rude/iota souscrit + accent aigu */
    DEADTRANS( 0x1fef , 0x03ea , 0x03e4 , DKF_DEAD), /* esprit rude/iota souscrit + accent grave */
    DEADTRANS( 0x1fc0 , 0x03ea , 0x03e8 , DKF_DEAD), /* esprit rude/iota souscrit + circonflexe */

	/* accent aigu */
    DEADTRANS( L' '   , 0x1ffd , 0x1ffd , 0x0000),
    DEADTRANS( 0x03b1 , 0x1ffd , 0x1f71 , 0x0000),
    DEADTRANS( 0x1fb3 , 0x1ffd , 0x1fb4 , 0x0000),
    DEADTRANS( 0x1f00 , 0x1ffd , 0x1f04 , 0x0000),
    DEADTRANS( 0x1f01 , 0x1ffd , 0x1f05 , 0x0000),
    DEADTRANS( 0x0391 , 0x1ffd , 0x1fbb , 0x0000),
    DEADTRANS( 0x1fbc , 0x1ffd , 0x03ef , 0x0000),
    DEADTRANS( 0x1f08 , 0x1ffd , 0x1f0c , 0x0000),
    DEADTRANS( 0x1f09 , 0x1ffd , 0x1f0d , 0x0000),
    DEADTRANS( 0x03b5 , 0x1ffd , 0x1f73 , 0x0000),
    DEADTRANS( 0x1f10 , 0x1ffd , 0x1f14 , 0x0000),
    DEADTRANS( 0x1f11 , 0x1ffd , 0x1f15 , 0x0000),
    DEADTRANS( 0x0395 , 0x1ffd , 0x1fc9 , 0x0000),
    DEADTRANS( 0x1f18 , 0x1ffd , 0x1f1c , 0x0000),
    DEADTRANS( 0x1f19 , 0x1ffd , 0x1f1d , 0x0000),
    DEADTRANS( 0x03b7 , 0x1ffd , 0x1f75 , 0x0000),
    DEADTRANS( 0x1fc3 , 0x1ffd , 0x1fc4 , 0x0000),
    DEADTRANS( 0x1f20 , 0x1ffd , 0x1f24 , 0x0000),
    DEADTRANS( 0x1f21 , 0x1ffd , 0x1f25 , 0x0000),
    DEADTRANS( 0x0397 , 0x1ffd , 0x1fcb , 0x0000),
    DEADTRANS( 0x1fcc , 0x1ffd , 0x03f4 , 0x0000),
    DEADTRANS( 0x1f28 , 0x1ffd , 0x1f2c , 0x0000),
    DEADTRANS( 0x1f29 , 0x1ffd , 0x1f2d , 0x0000),
    DEADTRANS( 0x03b9 , 0x1ffd , 0x1f77 , 0x0000),
    DEADTRANS( 0x1f30 , 0x1ffd , 0x1f34 , 0x0000),
    DEADTRANS( 0x1f31 , 0x1ffd , 0x1f35 , 0x0000),
    DEADTRANS( 0x0399 , 0x1ffd , 0x1fdb , 0x0000),
    DEADTRANS( 0x1f38 , 0x1ffd , 0x1f3c , 0x0000),
    DEADTRANS( 0x1f39 , 0x1ffd , 0x1f3d , 0x0000),
    DEADTRANS( 0x03bf , 0x1ffd , 0x1f79 , 0x0000),
    DEADTRANS( 0x1f40 , 0x1ffd , 0x1f44 , 0x0000),
    DEADTRANS( 0x1f41 , 0x1ffd , 0x1f45 , 0x0000),
    DEADTRANS( 0x039f , 0x1ffd , 0x1ff9 , 0x0000),
    DEADTRANS( 0x1f48 , 0x1ffd , 0x1f4c , 0x0000),
    DEADTRANS( 0x1f49 , 0x1ffd , 0x1f4d , 0x0000),
    DEADTRANS( 0x03c5 , 0x1ffd , 0x1f7b , 0x0000),
    DEADTRANS( 0x1f50 , 0x1ffd , 0x1f54 , 0x0000),
    DEADTRANS( 0x1f51 , 0x1ffd , 0x1f55 , 0x0000),
    DEADTRANS( 0x03a5 , 0x1ffd , 0x1feb , 0x0000),
    DEADTRANS( 0x1f58 , 0x1ffd , 0x1f5c , 0x0000),
    DEADTRANS( 0x1f59 , 0x1ffd , 0x1f5d , 0x0000),
    DEADTRANS( 0x03c9 , 0x1ffd , 0x1f7d , 0x0000),
    DEADTRANS( 0x1ff3 , 0x1ffd , 0x1ff4 , 0x0000),
    DEADTRANS( 0x1f60 , 0x1ffd , 0x1f64 , 0x0000),
    DEADTRANS( 0x1f61 , 0x1ffd , 0x1f65 , 0x0000),
    DEADTRANS( 0x03a9 , 0x1ffd , 0x1ffb , 0x0000),
    DEADTRANS( 0x1ffc , 0x1ffd , 0x03f8 , 0x0000),
    DEADTRANS( 0x1f68 , 0x1ffd , 0x1f6c , 0x0000),
    DEADTRANS( 0x1f69 , 0x1ffd , 0x1f6d , 0x0000),
    DEADTRANS( 0x1fbf , 0x1ffd , 0x1fce , DKF_DEAD), /* accent aigu + esprit doux */
    DEADTRANS( 0x1ffe , 0x1ffd , 0x1fde , DKF_DEAD), /* accent aigu + esprit rude */
    DEADTRANS( 0x1fbe , 0x1ffd , 0x03e2 , DKF_DEAD), /* accent aigu + iota souscrit */
    DEADTRANS( 0x03eb , 0x1ffd , 0x03e7 , DKF_DEAD), /* accent aigu + esprit doux/iota souscrit */
    DEADTRANS( 0x03ea , 0x1ffd , 0x03e5 , DKF_DEAD), /* accent aigu + esprit rude/iota souscrit */
    DEADTRANS( 0x00a8 , 0x1ffd , 0x1fee , DKF_DEAD), /* accent aigu + trema */

	/* esprit doux/accent aigu */
    DEADTRANS( L' '   , 0x1fce , 0x1fce , 0x0000),
    DEADTRANS( 0x03b1 , 0x1fce , 0x1f04 , 0x0000),
    DEADTRANS( 0x1fb3 , 0x1fce , 0x1f84 , 0x0000),
    DEADTRANS( 0x0391 , 0x1fce , 0x1f0c , 0x0000),
    DEADTRANS( 0x1fbc , 0x1fce , 0x1f8c , 0x0000),
    DEADTRANS( 0x03b5 , 0x1fce , 0x1f14 , 0x0000),
    DEADTRANS( 0x0395 , 0x1fce , 0x1f1c , 0x0000),
    DEADTRANS( 0x03b7 , 0x1fce , 0x1f24 , 0x0000),
    DEADTRANS( 0x1fc3 , 0x1fce , 0x1f94 , 0x0000),
    DEADTRANS( 0x0397 , 0x1fce , 0x1f2c , 0x0000),
    DEADTRANS( 0x1fcc , 0x1fce , 0x1f9c , 0x0000),
    DEADTRANS( 0x03b9 , 0x1fce , 0x1f34 , 0x0000),
    DEADTRANS( 0x0399 , 0x1fce , 0x1f3c , 0x0000),
    DEADTRANS( 0x03bf , 0x1fce , 0x1f44 , 0x0000),
    DEADTRANS( 0x039f , 0x1fce , 0x1f4c , 0x0000),
    DEADTRANS( 0x03c5 , 0x1fce , 0x1f54 , 0x0000),
    DEADTRANS( 0x03a5 , 0x1fce , 0x1f5c , 0x0000),
    DEADTRANS( 0x03c9 , 0x1fce , 0x1f64 , 0x0000),
    DEADTRANS( 0x1ff3 , 0x1fce , 0x1fa4 , 0x0000),
    DEADTRANS( 0x03a9 , 0x1fce , 0x1f6c , 0x0000),
    DEADTRANS( 0x1ffc , 0x1fce , 0x1fac , 0x0000),
    DEADTRANS( 0x1fbe , 0x1fce , 0x03e7 , DKF_DEAD), /* esprit doux/accent aigu + iota souscrit */

	/* accent aigu/iota souscrit */
    DEADTRANS( L' '   , 0x03e2 , 0x03e2 , 0x0000),
    DEADTRANS( 0x03b1 , 0x03e2 , 0x1fb4 , 0x0000),
    DEADTRANS( 0x1f00 , 0x03e2 , 0x1f84 , 0x0000),
    DEADTRANS( 0x1f01 , 0x03e2 , 0x1f85 , 0x0000),
    DEADTRANS( 0x0391 , 0x03e2 , 0x03ef , 0x0000),
    DEADTRANS( 0x1f08 , 0x03e2 , 0x1f8c , 0x0000),
    DEADTRANS( 0x1f09 , 0x03e2 , 0x1f8d , 0x0000),
    DEADTRANS( 0x03b7 , 0x03e2 , 0x1fc4 , 0x0000),
    DEADTRANS( 0x1f20 , 0x03e2 , 0x1f94 , 0x0000),
    DEADTRANS( 0x1f21 , 0x03e2 , 0x1f95 , 0x0000),
    DEADTRANS( 0x0397 , 0x03e2 , 0x03f4 , 0x0000),
    DEADTRANS( 0x1f28 , 0x03e2 , 0x1f9c , 0x0000),
    DEADTRANS( 0x1f29 , 0x03e2 , 0x1f9d , 0x0000),
    DEADTRANS( 0x03c9 , 0x03e2 , 0x1ff4 , 0x0000),
    DEADTRANS( 0x1f60 , 0x03e2 , 0x1fa4 , 0x0000),
    DEADTRANS( 0x1f61 , 0x03e2 , 0x1fa5 , 0x0000),
    DEADTRANS( 0x03a9 , 0x03e2 , 0x03f8 , 0x0000),
    DEADTRANS( 0x1f68 , 0x03e2 , 0x1fac , 0x0000),
    DEADTRANS( 0x1f69 , 0x03e2 , 0x1fad , 0x0000),
    DEADTRANS( 0x1fbf , 0x03e2 , 0x03e7 , DKF_DEAD), /* accent aigu/iota souscrit + esprit doux */
    DEADTRANS( 0x1ffe , 0x03e2 , 0x03e5 , DKF_DEAD), /* accent aigu/iota souscrit + esprit rude */

	/* macron */
    DEADTRANS( L' '   , 0x02c9 , 0x02c9 , 0x0000),
    DEADTRANS( 0x03b1 , 0x02c9 , 0x1fb1 , 0x0000),
    DEADTRANS( 0x0391 , 0x02c9 , 0x1fb9 , 0x0000),
    DEADTRANS( 0x03b9 , 0x02c9 , 0x1fd1 , 0x0000),
    DEADTRANS( 0x0399 , 0x02c9 , 0x1fd9 , 0x0000),
    DEADTRANS( 0x03c5 , 0x02c9 , 0x1fe1 , 0x0000),
    DEADTRANS( 0x03a5 , 0x02c9 , 0x1fe9 , 0x0000),

	/* iota souscrit */
    DEADTRANS( L' '   , 0x1fbe , 0x1fbe , 0x0000),
    DEADTRANS( 0x03b1 , 0x1fbe , 0x1fb3 , 0x0000),
    DEADTRANS( 0x0391 , 0x1fbe , 0x1fbc , 0x0000),
    DEADTRANS( 0x03b7 , 0x1fbe , 0x1fc3 , 0x0000),
    DEADTRANS( 0x0397 , 0x1fbe , 0x1fcc , 0x0000),
    DEADTRANS( 0x03c9 , 0x1fbe , 0x1ff3 , 0x0000),
    DEADTRANS( 0x03a9 , 0x1fbe , 0x1ffc , 0x0000),
    DEADTRANS( 0x1f01 , 0x1fbe , 0x1f81 , 0x0000),
    DEADTRANS( 0x1f00 , 0x1fbe , 0x1f80 , 0x0000),
    DEADTRANS( 0x1fb6 , 0x1fbe , 0x1fb7 , 0x0000),
    DEADTRANS( 0x1fb3 , 0x1fbe , 0x03b1 , 0x0000),
    DEADTRANS( 0x1f08 , 0x1fbe , 0x1f88 , 0x0000),
    DEADTRANS( 0x1f09 , 0x1fbe , 0x1f89 , 0x0000),
    DEADTRANS( 0x03ec , 0x1fbe , 0x03ed , 0x0000),
    DEADTRANS( 0x1fbc , 0x1fbe , 0x0391 , 0x0000),
    DEADTRANS( 0x1f20 , 0x1fbe , 0x1f90 , 0x0000),
    DEADTRANS( 0x1f21 , 0x1fbe , 0x1f91 , 0x0000),
    DEADTRANS( 0x1fc6 , 0x1fbe , 0x1fc7 , 0x0000),
    DEADTRANS( 0x1fc3 , 0x1fbe , 0x03b7 , 0x0000),
    DEADTRANS( 0x1f28 , 0x1fbe , 0x1f98 , 0x0000),
    DEADTRANS( 0x1f29 , 0x1fbe , 0x1f99 , 0x0000),
    DEADTRANS( 0x03f1 , 0x1fbe , 0x03f2 , 0x0000),
    DEADTRANS( 0x1fcc , 0x1fbe , 0x0397 , 0x0000),
    DEADTRANS( 0x1f60 , 0x1fbe , 0x1fa0 , 0x0000),
    DEADTRANS( 0x1f61 , 0x1fbe , 0x1fa1 , 0x0000),
    DEADTRANS( 0x1ff6 , 0x1fbe , 0x1ff7 , 0x0000),
    DEADTRANS( 0x1ff3 , 0x1fbe , 0x03c9 , 0x0000),
    DEADTRANS( 0x1f68 , 0x1fbe , 0x1fa8 , 0x0000),
    DEADTRANS( 0x1f69 , 0x1fbe , 0x1fa9 , 0x0000),
    DEADTRANS( 0x03f5 , 0x1fbe , 0x03f6 , 0x0000),
    DEADTRANS( 0x1ffc , 0x1fbe , 0x03a9 , 0x0000),
    DEADTRANS( 0x1ffd , 0x1fbe , 0x03e2 , DKF_DEAD), /* iota souscrit + accent aigu */
    DEADTRANS( 0x1fef , 0x1fbe , 0x03e3 , DKF_DEAD), /* iota souscrit + accent grave */
    DEADTRANS( 0x1fc0 , 0x1fbe , 0x0342 , DKF_DEAD), /* iota souscrit + circonflexe */
    DEADTRANS( 0x1fbf , 0x1fbe , 0x03eb , DKF_DEAD), /* iota souscrit + esprit doux */
    DEADTRANS( 0x1fce , 0x1fbe , 0x03e7 , DKF_DEAD), /* iota souscrit + accent aigu/esprit doux */
    DEADTRANS( 0x1fcd , 0x1fbe , 0x03e6 , DKF_DEAD), /* iota souscrit + accent grave/esprit doux */
    DEADTRANS( 0x1fcf , 0x1fbe , 0x03e9 , DKF_DEAD), /* iota souscrit + circonflexe/esprit doux */
    DEADTRANS( 0x1ffe , 0x1fbe , 0x03ea , DKF_DEAD), /* iota souscrit + esprit rude */
    DEADTRANS( 0x1fde , 0x1fbe , 0x03e5 , DKF_DEAD), /* iota souscrit + accent aigu/esprit rude */
    DEADTRANS( 0x1fdd , 0x1fbe , 0x03e4 , DKF_DEAD), /* iota souscrit + accent grave/esprit rude */
    DEADTRANS( 0x1fdf , 0x1fbe , 0x03e8 , DKF_DEAD), /* iota souscrit + circonflexe/esprit rude */

	/* trema */
    DEADTRANS( L' '   , 0x00a8 , 0x00a8 , 0x0000),
    DEADTRANS( 0x03b9 , 0x00a8 , 0x03ca , 0x0000),
    DEADTRANS( 0x1fd6 , 0x00a8 , 0x1fd7 , 0x0000),
    DEADTRANS( 0x0399 , 0x00a8 , 0x03aa , 0x0000),
    DEADTRANS( 0x03fa , 0x00a8 , 0x03ff , 0x0000),
    DEADTRANS( 0x03c5 , 0x00a8 , 0x03cb , 0x0000),
    DEADTRANS( 0x1fe6 , 0x00a8 , 0x1fe7 , 0x0000),
    DEADTRANS( 0x03a5 , 0x00a8 , 0x03ab , 0x0000),
    DEADTRANS( 0x03f9 , 0x00a8 , 0x03fd , 0x0000),
    DEADTRANS( 0x1ffd , 0x00a8 , 0x1fee , DKF_DEAD), /* trema + accent aigu */
    DEADTRANS( 0x1fef , 0x00a8 , 0x1fed , DKF_DEAD), /* trema + accent grave */
    DEADTRANS( 0x1fc0 , 0x00a8 , 0x1fc1 , DKF_DEAD), /* trema + circonflexe */

	/* trema circonflexe */
    DEADTRANS( L' '   , 0x1fc1 , 0x1fc1 , 0x0000),
    DEADTRANS( 0x03b9 , 0x1fc1 , 0x1fd7 , 0x0000),
    DEADTRANS( 0x0399 , 0x1fc1 , 0x03ff , 0x0000),
    DEADTRANS( 0x03c5 , 0x1fc1 , 0x1fe7 , 0x0000),
    DEADTRANS( 0x03a5 , 0x1fc1 , 0x03fd , 0x0000),

	/* accent grave */
    DEADTRANS( L' '   , 0x1fef , 0x1fef , 0x0000),
    DEADTRANS( 0x03b1 , 0x1fef , 0x1f70 , 0x0000),
    DEADTRANS( 0x1fb3 , 0x1fef , 0x1fb2 , 0x0000),
    DEADTRANS( 0x1f00 , 0x1fef , 0x1f02 , 0x0000),
    DEADTRANS( 0x1f01 , 0x1fef , 0x1f03 , 0x0000),
    DEADTRANS( 0x0391 , 0x1fef , 0x1fba , 0x0000),
    DEADTRANS( 0x1fbc , 0x1fef , 0x03ee , 0x0000),
    DEADTRANS( 0x1f08 , 0x1fef , 0x1f0a , 0x0000),
    DEADTRANS( 0x1f09 , 0x1fef , 0x1f0b , 0x0000),
    DEADTRANS( 0x03b5 , 0x1fef , 0x1f72 , 0x0000),
    DEADTRANS( 0x1f10 , 0x1fef , 0x1f12 , 0x0000),
    DEADTRANS( 0x1f11 , 0x1fef , 0x1f13 , 0x0000),
    DEADTRANS( 0x0395 , 0x1fef , 0x1fc8 , 0x0000),
    DEADTRANS( 0x1f18 , 0x1fef , 0x1f1a , 0x0000),
    DEADTRANS( 0x1f19 , 0x1fef , 0x1f1b , 0x0000),
    DEADTRANS( 0x03b7 , 0x1fef , 0x1f74 , 0x0000),
    DEADTRANS( 0x1fc3 , 0x1fef , 0x1fc2 , 0x0000),
    DEADTRANS( 0x1f20 , 0x1fef , 0x1f22 , 0x0000),
    DEADTRANS( 0x1f21 , 0x1fef , 0x1f23 , 0x0000),
    DEADTRANS( 0x0397 , 0x1fef , 0x1fca , 0x0000),
    DEADTRANS( 0x1fcc , 0x1fef , 0x03f3 , 0x0000),
    DEADTRANS( 0x1f28 , 0x1fef , 0x1f2a , 0x0000),
    DEADTRANS( 0x1f29 , 0x1fef , 0x1f2b , 0x0000),
    DEADTRANS( 0x03b9 , 0x1fef , 0x1f76 , 0x0000),
    DEADTRANS( 0x1f30 , 0x1fef , 0x1f32 , 0x0000),
    DEADTRANS( 0x1f31 , 0x1fef , 0x1f33 , 0x0000),
    DEADTRANS( 0x0399 , 0x1fef , 0x1fda , 0x0000),
    DEADTRANS( 0x1f38 , 0x1fef , 0x1f3a , 0x0000),
    DEADTRANS( 0x1f39 , 0x1fef , 0x1f3b , 0x0000),
    DEADTRANS( 0x03bf , 0x1fef , 0x1f78 , 0x0000),
    DEADTRANS( 0x1f40 , 0x1fef , 0x1f42 , 0x0000),
    DEADTRANS( 0x1f41 , 0x1fef , 0x1f43 , 0x0000),
    DEADTRANS( 0x039f , 0x1fef , 0x1ff8 , 0x0000),
    DEADTRANS( 0x1f48 , 0x1fef , 0x1f4a , 0x0000),
    DEADTRANS( 0x1f49 , 0x1fef , 0x1f4b , 0x0000),
    DEADTRANS( 0x03c5 , 0x1fef , 0x1f7a , 0x0000),
    DEADTRANS( 0x1f50 , 0x1fef , 0x1f52 , 0x0000),
    DEADTRANS( 0x1f51 , 0x1fef , 0x1f53 , 0x0000),
    DEADTRANS( 0x03a5 , 0x1fef , 0x1fea , 0x0000),
    DEADTRANS( 0x1f58 , 0x1fef , 0x1f5a , 0x0000),
    DEADTRANS( 0x1f59 , 0x1fef , 0x1f5b , 0x0000),
    DEADTRANS( 0x03c9 , 0x1fef , 0x1f7c , 0x0000),
    DEADTRANS( 0x1ff3 , 0x1fef , 0x1ff2 , 0x0000),
    DEADTRANS( 0x1f60 , 0x1fef , 0x1f62 , 0x0000),
    DEADTRANS( 0x1f61 , 0x1fef , 0x1f63 , 0x0000),
    DEADTRANS( 0x03a9 , 0x1fef , 0x1ffa , 0x0000),
    DEADTRANS( 0x1ffc , 0x1fef , 0x03f7 , 0x0000),
    DEADTRANS( 0x1f68 , 0x1fef , 0x1f6a , 0x0000),
    DEADTRANS( 0x1f69 , 0x1fef , 0x1f6b , 0x0000),
    DEADTRANS( 0x1fbf , 0x1fef , 0x1fcd , DKF_DEAD), /* accent grave + esprit doux */
    DEADTRANS( 0x1ffe , 0x1fef , 0x1fdd , DKF_DEAD), /* accent grave + esprit rude */
    DEADTRANS( 0x1fbe , 0x1fef , 0x03e3 , DKF_DEAD), /* accent grave + iota souscrit */
    DEADTRANS( 0x03eb , 0x1fef , 0x03e6 , DKF_DEAD), /* accent grave + esprit doux/iota souscrit */
    DEADTRANS( 0x03ea , 0x1fef , 0x03e4 , DKF_DEAD), /* accent grave + esprit rude/iota souscrit */
    DEADTRANS( 0x00a8 , 0x1fef , 0x1fed , DKF_DEAD), /* accent grave + trema */

	/* esprit rude/accent aigu */
    DEADTRANS( L' '   , 0x1fde , 0x1fde , 0x0000),
    DEADTRANS( 0x03b1 , 0x1fde , 0x1f05 , 0x0000),
    DEADTRANS( 0x1fb3 , 0x1fde , 0x1f85 , 0x0000),
    DEADTRANS( 0x0391 , 0x1fde , 0x1f0d , 0x0000),
    DEADTRANS( 0x1fbc , 0x1fde , 0x1f8d , 0x0000),
    DEADTRANS( 0x03b5 , 0x1fde , 0x1f15 , 0x0000),
    DEADTRANS( 0x0395 , 0x1fde , 0x1f1d , 0x0000),
    DEADTRANS( 0x03b7 , 0x1fde , 0x1f25 , 0x0000),
    DEADTRANS( 0x1fc3 , 0x1fde , 0x1f95 , 0x0000),
    DEADTRANS( 0x0397 , 0x1fde , 0x1f2d , 0x0000),
    DEADTRANS( 0x1fcc , 0x1fde , 0x1f9d , 0x0000),
    DEADTRANS( 0x03b9 , 0x1fde , 0x1f35 , 0x0000),
    DEADTRANS( 0x0399 , 0x1fde , 0x1f3d , 0x0000),
    DEADTRANS( 0x03bf , 0x1fde , 0x1f45 , 0x0000),
    DEADTRANS( 0x039f , 0x1fde , 0x1f4d , 0x0000),
    DEADTRANS( 0x03c5 , 0x1fde , 0x1f55 , 0x0000),
    DEADTRANS( 0x03a5 , 0x1fde , 0x1f5d , 0x0000),
    DEADTRANS( 0x03c9 , 0x1fde , 0x1f65 , 0x0000),
    DEADTRANS( 0x1ff3 , 0x1fde , 0x1fa5 , 0x0000),
    DEADTRANS( 0x03a9 , 0x1fde , 0x1f6d , 0x0000),
    DEADTRANS( 0x1ffc , 0x1fde , 0x1fad , 0x0000),
    DEADTRANS( 0x1fbe , 0x1fde , 0x03e5 , DKF_DEAD), /* esprit rude/accent aigu + iota souscrit */

	/* accent grave/iota souscrit */
    DEADTRANS( L' '   , 0x03e3 , 0x03e3 , 0x0000),
    DEADTRANS( 0x03b1 , 0x03e3 , 0x1fb2 , 0x0000),
    DEADTRANS( 0x1f00 , 0x03e3 , 0x1f82 , 0x0000),
    DEADTRANS( 0x1f01 , 0x03e3 , 0x1f83 , 0x0000),
    DEADTRANS( 0x0391 , 0x03e3 , 0x03ee , 0x0000),
    DEADTRANS( 0x1f08 , 0x03e3 , 0x1f8a , 0x0000),
    DEADTRANS( 0x1f09 , 0x03e3 , 0x1f8b , 0x0000),
    DEADTRANS( 0x03b7 , 0x03e3 , 0x1fc2 , 0x0000),
    DEADTRANS( 0x1f20 , 0x03e3 , 0x1f92 , 0x0000),
    DEADTRANS( 0x1f21 , 0x03e3 , 0x1f93 , 0x0000),
    DEADTRANS( 0x0397 , 0x03e3 , 0x03f3 , 0x0000),
    DEADTRANS( 0x1f28 , 0x03e3 , 0x1f9a , 0x0000),
    DEADTRANS( 0x1f29 , 0x03e3 , 0x1f9b , 0x0000),
    DEADTRANS( 0x03c9 , 0x03e3 , 0x1ff2 , 0x0000),
    DEADTRANS( 0x1f60 , 0x03e3 , 0x1fa2 , 0x0000),
    DEADTRANS( 0x1f61 , 0x03e3 , 0x1fa3 , 0x0000),
    DEADTRANS( 0x03a9 , 0x03e3 , 0x03f7 , 0x0000),
    DEADTRANS( 0x1f68 , 0x03e3 , 0x1faa , 0x0000),
    DEADTRANS( 0x1f69 , 0x03e3 , 0x1fab , 0x0000),
    DEADTRANS( 0x1fbf , 0x03e3 , 0x03e6 , DKF_DEAD), /* accent grave/iota souscrit + esprit doux */
    DEADTRANS( 0x1ffe , 0x03e3 , 0x03e4 , DKF_DEAD), /* accent grave/iota souscrit + esprit rude */

	/* vracky */
    DEADTRANS( L' '   , 0x02d8 , 0x02d8 , 0x0000),
    DEADTRANS( 0x03b1 , 0x02d8 , 0x1fb0 , 0x0000),
    DEADTRANS( 0x0391 , 0x02d8 , 0x1fb8 , 0x0000),
    DEADTRANS( 0x03b9 , 0x02d8 , 0x1fd0 , 0x0000),
    DEADTRANS( 0x0399 , 0x02d8 , 0x1fd8 , 0x0000),
    DEADTRANS( 0x03c5 , 0x02d8 , 0x1fe0 , 0x0000),
    DEADTRANS( 0x03a5 , 0x02d8 , 0x1fe8 , 0x0000),

	/* circonflexe */
    DEADTRANS( L' '   , 0x1fc0   , 0x1fc0 , 0x0000),
    DEADTRANS( 0x03b1 , 0x1fc0   , 0x1fb6 , 0x0000),
    DEADTRANS( 0x1fb6 , 0x1fc0   , 0x03b1 , 0x0000),
    DEADTRANS( 0x1fb3 , 0x1fc0   , 0x1fb7 , 0x0000),
    DEADTRANS( 0x1f00 , 0x1fc0   , 0x1f06 , 0x0000),
    DEADTRANS( 0x1f01 , 0x1fc0   , 0x1f07 , 0x0000),
    DEADTRANS( 0x0391 , 0x1fc0   , 0x03ec , 0x0000),
    DEADTRANS( 0x03ec , 0x1fc0   , 0x0391 , 0x0000),
    DEADTRANS( 0x1fbc , 0x1fc0   , 0x03ed , 0x0000),
    DEADTRANS( 0x1f08 , 0x1fc0   , 0x1f0e , 0x0000),
    DEADTRANS( 0x1f09 , 0x1fc0   , 0x1f0f , 0x0000),
    DEADTRANS( 0x03b7 , 0x1fc0   , 0x1fc6 , 0x0000),
    DEADTRANS( 0x1fc6 , 0x1fc0   , 0x03b7 , 0x0000),
    DEADTRANS( 0x1fc3 , 0x1fc0   , 0x1fc7 , 0x0000),
    DEADTRANS( 0x1f20 , 0x1fc0   , 0x1f26 , 0x0000),
    DEADTRANS( 0x1f21 , 0x1fc0   , 0x1f27 , 0x0000),
    DEADTRANS( 0x0397 , 0x1fc0   , 0x03f1 , 0x0000),
    DEADTRANS( 0x03f1 , 0x1fc0   , 0x0397 , 0x0000),
    DEADTRANS( 0x1fcc , 0x1fc0   , 0x03f2 , 0x0000),
    DEADTRANS( 0x1f28 , 0x1fc0   , 0x1f2e , 0x0000),
    DEADTRANS( 0x1f29 , 0x1fc0   , 0x1f2f , 0x0000),
    DEADTRANS( 0x03b9 , 0x1fc0   , 0x1fd6 , 0x0000),
    DEADTRANS( 0x1fd6 , 0x1fc0   , 0x03b9 , 0x0000),
    DEADTRANS( 0x1f30 , 0x1fc0   , 0x1f36 , 0x0000),
    DEADTRANS( 0x1f31 , 0x1fc0   , 0x1f37 , 0x0000),
    DEADTRANS( 0x0399 , 0x1fc0   , 0x03fa , 0x0000),
    DEADTRANS( 0x03fa , 0x1fc0   , 0x0399 , 0x0000),
    DEADTRANS( 0x1f38 , 0x1fc0   , 0x1f3e , 0x0000),
    DEADTRANS( 0x1f39 , 0x1fc0   , 0x1f3f , 0x0000),
    DEADTRANS( 0x03c5 , 0x1fc0   , 0x1fe6 , 0x0000),
    DEADTRANS( 0x1fe6 , 0x1fc0   , 0x03c5 , 0x0000),
    DEADTRANS( 0x1f50 , 0x1fc0   , 0x1f56 , 0x0000),
    DEADTRANS( 0x1f51 , 0x1fc0   , 0x1f57 , 0x0000),
    DEADTRANS( 0x03a5 , 0x1fc0   , 0x03f9 , 0x0000),
    DEADTRANS( 0x03f9 , 0x1fc0   , 0x03a5 , 0x0000),
    DEADTRANS( 0x1f58 , 0x1fc0   , 0x1f5e , 0x0000),
    DEADTRANS( 0x1f59 , 0x1fc0   , 0x1f5f , 0x0000),
    DEADTRANS( 0x03c9 , 0x1fc0   , 0x1ff6 , 0x0000),
    DEADTRANS( 0x1ff6 , 0x1fc0   , 0x03c9 , 0x0000),
    DEADTRANS( 0x1ff3 , 0x1fc0   , 0x1ff7 , 0x0000),
    DEADTRANS( 0x1f60 , 0x1fc0   , 0x1f66 , 0x0000),
    DEADTRANS( 0x1f61 , 0x1fc0   , 0x1f67 , 0x0000),
    DEADTRANS( 0x03a9 , 0x1fc0   , 0x03f5 , 0x0000),
    DEADTRANS( 0x03f5 , 0x1fc0   , 0x03a9 , 0x0000),
    DEADTRANS( 0x1ffc , 0x1fc0   , 0x03f6 , 0x0000),
    DEADTRANS( 0x1f68 , 0x1fc0   , 0x1f6e , 0x0000),
    DEADTRANS( 0x1f69 , 0x1fc0   , 0x1f6f , 0x0000),
    DEADTRANS( 0x1fbf , 0x1fc0   , 0x1fcf , DKF_DEAD), /* circonflexe + esprit doux */
    DEADTRANS( 0x1ffe , 0x1fc0   , 0x1fdf , DKF_DEAD), /* circonflexe + esprit rude */
    DEADTRANS( 0x00a8 , 0x1fc0   , 0x1fc1 , DKF_DEAD), /* circonflexe + trema */
    DEADTRANS( 0x1fbe , 0x1fc0   , 0x0342 , DKF_DEAD), /* circonflexe + iota souscrit */
    DEADTRANS( 0x03eb , 0x1fc0   , 0x03e9 , DKF_DEAD), /* circonflexe + esprit doux/iota souscrit */
    DEADTRANS( 0x03ea , 0x1fc0   , 0x03e8 , DKF_DEAD), /* circonflexe + esprit rude/iota souscrit */

	/* circonflexe/iota souscrit */
    DEADTRANS( L' '   , 0x0342 , 0x0342 , 0x0000),
    DEADTRANS( 0x03b1 , 0x0342 , 0x1fb7 , 0x0000),
    DEADTRANS( 0x1f00 , 0x0342 , 0x1f86 , 0x0000),
    DEADTRANS( 0x1f01 , 0x0342 , 0x1f87 , 0x0000),
    DEADTRANS( 0x0391 , 0x0342 , 0x03ed , 0x0000),
    DEADTRANS( 0x1f08 , 0x0342 , 0x1f8e , 0x0000),
    DEADTRANS( 0x1f09 , 0x0342 , 0x1f8f , 0x0000),
    DEADTRANS( 0x03b7 , 0x0342 , 0x1fc7 , 0x0000),
    DEADTRANS( 0x1f20 , 0x0342 , 0x1f96 , 0x0000),
    DEADTRANS( 0x1f21 , 0x0342 , 0x1f97 , 0x0000),
    DEADTRANS( 0x0397 , 0x0342 , 0x03f2 , 0x0000),
    DEADTRANS( 0x1f28 , 0x0342 , 0x1f9e , 0x0000),
    DEADTRANS( 0x1f29 , 0x0342 , 0x1f9f , 0x0000),
    DEADTRANS( 0x03c9 , 0x0342 , 0x1ff7 , 0x0000),
    DEADTRANS( 0x1f60 , 0x0342 , 0x1fa6 , 0x0000),
    DEADTRANS( 0x1f61 , 0x0342 , 0x1fa7 , 0x0000),
    DEADTRANS( 0x03a9 , 0x0342 , 0x03f6 , 0x0000),
    DEADTRANS( 0x1f68 , 0x0342 , 0x1fae , 0x0000),
    DEADTRANS( 0x1f69 , 0x0342 , 0x1faf , 0x0000),
    DEADTRANS( 0x1fbf , 0x0342 , 0x03e9 , DKF_DEAD), /* circonflexe/iota souscrit + esprit doux */
    DEADTRANS( 0x1ffe , 0x0342 , 0x03e8 , DKF_DEAD), /* circonflexe/iota souscrit + esprit rude */

	/* Numbers */
    DEADTRANS( L' '   , 0x043C , 0x043C , 0x0000),
    DEADTRANS( 0x03B1 , 0x043C , 0x041B , 0x0000), /* alpha */
    DEADTRANS( 0x03B2 , 0x043C , 0x041C , 0x0000), /* beta */
    DEADTRANS( 0x03B3 , 0x043C , 0x041D , 0x0000), /* gamma */
    DEADTRANS( 0x03B4 , 0x043C , 0x041E , 0x0000), /* delta */
    DEADTRANS( 0x03B5 , 0x043C , 0x041F , 0x0000), /* epsilon */
    DEADTRANS( 0x03B6 , 0x043C , 0x0420 , 0x0000), /* zeta */
    DEADTRANS( 0x03B7 , 0x043C , 0x0421 , 0x0000), /* eta */
    DEADTRANS( 0x03B8 , 0x043C , 0x0422 , 0x0000), /* theta */
    DEADTRANS( 0x03B9 , 0x043C , 0x0423 , 0x0000), /* iota */
    DEADTRANS( 0x03BA , 0x043C , 0x0424 , 0x0000), /* kappa */
    DEADTRANS( 0x03BB , 0x043C , 0x0425 , 0x0000), /* lambda */
    DEADTRANS( 0x03BC , 0x043C , 0x0426 , 0x0000), /* mu */
    DEADTRANS( 0x03BD , 0x043C , 0x0427 , 0x0000), /* nu */
    DEADTRANS( 0x03BE , 0x043C , 0x0428 , 0x0000), /* xi */
    DEADTRANS( 0x03BF , 0x043C , 0x0429 , 0x0000), /* omicron */
    DEADTRANS( 0x03C0 , 0x043C , 0x042A , 0x0000), /* pi */
    DEADTRANS( 0x03C1 , 0x043C , 0x042B , 0x0000), /* rho */
    DEADTRANS( 0x03C2 , 0x043C , 0x042C , 0x0000), /* sigma final */
    DEADTRANS( 0x03C3 , 0x043C , 0x042D , 0x0000), /* sigma */
    DEADTRANS( 0x03C4 , 0x043C , 0x042E , 0x0000), /* tau */
    DEADTRANS( 0x03C5 , 0x043C , 0x042F , 0x0000), /* upsilon */
    DEADTRANS( 0x03C6 , 0x043C , 0x0430 , 0x0000), /* phi */
    DEADTRANS( 0x03C7 , 0x043C , 0x0431 , 0x0000), /* chi */
    DEADTRANS( 0x03C8 , 0x043C , 0x0432 , 0x0000), /* psi */
    DEADTRANS( 0x03C9 , 0x043C , 0x0433 , 0x0000), /* omega */
    DEADTRANS( 0x0391 , 0x043C , 0x0402 , 0x0000), /* alpha maj */
    DEADTRANS( 0x0392 , 0x043C , 0x0403 , 0x0000), /* beta maj */
    DEADTRANS( 0x0393 , 0x043C , 0x0404 , 0x0000), /* gamma maj */
    DEADTRANS( 0x0394 , 0x043C , 0x0405 , 0x0000), /* delta maj */
    DEADTRANS( 0x0395 , 0x043C , 0x0406 , 0x0000), /* epsilon maj */
    DEADTRANS( 0x0396 , 0x043C , 0x0407 , 0x0000), /* zeta maj */
    DEADTRANS( 0x0397 , 0x043C , 0x0408 , 0x0000), /* eta maj */
    DEADTRANS( 0x0398 , 0x043C , 0x0409 , 0x0000), /* theta maj */
    DEADTRANS( 0x0399 , 0x043C , 0x040A , 0x0000), /* iota maj */
    DEADTRANS( 0x039A , 0x043C , 0x040B , 0x0000), /* kappa maj */
    DEADTRANS( 0x039B , 0x043C , 0x040C , 0x0000), /* lambda maj */
    DEADTRANS( 0x039C , 0x043C , 0x040D , 0x0000), /* mu maj */
    DEADTRANS( 0x039D , 0x043C , 0x040E , 0x0000), /* nu maj */
    DEADTRANS( 0x039E , 0x043C , 0x040F , 0x0000), /* xi maj */
    DEADTRANS( 0x039F , 0x043C , 0x0410 , 0x0000), /* omicron maj */
    DEADTRANS( 0x03A0 , 0x043C , 0x0411 , 0x0000), /* pi maj */
    DEADTRANS( 0x03A1 , 0x043C , 0x0412 , 0x0000), /* rho maj */
    DEADTRANS( 0x03A3 , 0x043C , 0x0413 , 0x0000), /* sigma maj */
    DEADTRANS( 0x03A4 , 0x043C , 0x0414 , 0x0000), /* tau maj */
    DEADTRANS( 0x03A5 , 0x043C , 0x0415 , 0x0000), /* upsilon maj */
    DEADTRANS( 0x03A6 , 0x043C , 0x0416 , 0x0000), /* phi maj */
    DEADTRANS( 0x03A7 , 0x043C , 0x0417 , 0x0000), /* chi maj */
    DEADTRANS( 0x03A8 , 0x043C , 0x0418 , 0x0000), /* psi maj */
    DEADTRANS( 0x03A9 , 0x043C , 0x0419 , 0x0000), /* omega maj */
    DEADTRANS( 0x03DA , 0x043C , 0x0434 , 0x0000), /* stigma */
    DEADTRANS( 0x03DE , 0x043C , 0x0435 , 0x0000), /* koppa */
    DEADTRANS( 0x03DC , 0x043C , 0x043B , 0x0000), /* digamma */
    DEADTRANS( 0x03E0 , 0x043C , 0x0436 , 0x0000), /* sampi */
    DEADTRANS( 0x03D0 , 0x043C , 0x0437 , 0x0000), /* beta 2 */
    DEADTRANS( 0x03D1 , 0x043C , 0x0438 , 0x0000), /* theta 2 */
    DEADTRANS( 0x03D5 , 0x043C , 0x0439 , 0x0000), /* phi 2 */
    DEADTRANS( 0x03D6 , 0x043C , 0x043A , 0x0000), /* pi 2 */

    0, 0
};

static ALLOC_SECTION_LDATA LIGATURE2 aLigature[] = {
  {'3', 0, '\'', ' ' },
  {0 ,0 ,0 ,0 }
};

static ALLOC_SECTION_LDATA KBDTABLES KbdTables = {
    /*
     * Modifier keys
     */
    &CharModifiers,

    /*
     * Characters tables
     */
    aVkToWcharTable,

    /*
     * Diacritics
     */
    aDeadKey,

    /*
     * Names of Keys
     */
    aKeyNames,
    aKeyNamesExt,
    aKeyNamesDead,

    /*
     * Scan codes to Virtual Keys
     */
    ausVK,
    sizeof(ausVK) / sizeof(ausVK[0]),
    aE0VscToVk,
    aE1VscToVk,

    /*
     * Locale-specific special processing
     */
    MAKELONG(KLLF_ALTGR, KBD_VERSION),

    /*
     * Ligatures
     */
    2,
    sizeof(aLigature[0]),
    (PLIGATURE1)aLigature
};

PKBDTABLES KbdLayerDescriptor(VOID)
{
    return &KbdTables;
}
